# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request as APIRequest, Response as APIResponse, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.docs_apis = DocsApiService(self)
        



class DocsApiService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def meta(self, body, user_access_token=None, timeout=None):
        # type: (DocsApiMetaReqBody, str, int) -> DocsApiMetaReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocsApiMetaReqCall(self, body, request_opts=request_opts)

    def search(self, body, user_access_token=None, timeout=None):
        # type: (DocsApiSearchReqBody, str, int) -> DocsApiSearchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocsApiSearchReqCall(self, body, request_opts=request_opts)



class DocsApiMetaReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocsApiService, DocsApiMetaReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[DocsApiMetaResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/suite/docs-api/meta', 'POST', [ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=DocsApiMetaResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocsApiSearchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocsApiService, DocsApiSearchReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[DocsApiSearchResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/suite/docs-api/search/object', 'POST', [ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=DocsApiSearchResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request as APIRequest, Response as APIResponse, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.data_sources = DataSourceService(self)
        self.data_source_items = DataSourceItemService(self)
        



class DataSourceService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, timeout=None):
        # type: (DataSource, str, int) -> DataSourceCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DataSourceCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> DataSourceDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DataSourceDeleteReqCall(self, request_opts=request_opts)

    def get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> DataSourceGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DataSourceGetReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> DataSourceListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DataSourceListReqCall(self, request_opts=request_opts)

    def patch(self, body, tenant_key=None, timeout=None):
        # type: (DataSourcePatchReqBody, str, int) -> DataSourcePatchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DataSourcePatchReqCall(self, body, request_opts=request_opts)


class DataSourceItemService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, timeout=None):
        # type: (Item, str, int) -> DataSourceItemCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DataSourceItemCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> DataSourceItemDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DataSourceItemDeleteReqCall(self, request_opts=request_opts)

    def get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> DataSourceItemGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DataSourceItemGetReqCall(self, request_opts=request_opts)



class DataSourceCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DataSourceService, DataSource, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[DataSourceCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/search/v2/data_sources', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=DataSourceCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DataSourceDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DataSourceService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_data_source_id(self, data_source_id):
        # type: (str) -> DataSourceDeleteReqCall
        self.path_params['data_source_id'] = data_source_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/search/v2/data_sources/:data_source_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DataSourceGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DataSourceService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_data_source_id(self, data_source_id):
        # type: (str) -> DataSourceGetReqCall
        self.path_params['data_source_id'] = data_source_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[DataSourceGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/search/v2/data_sources/:data_source_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=DataSourceGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DataSourceListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DataSourceService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_view(self, view):
        # type: (int) -> DataSourceListReqCall
        self.query_params['view'] = view
        return self

    def set_page_token(self, page_token):
        # type: (str) -> DataSourceListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> DataSourceListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> APIResponse[Type[DataSourceListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/search/v2/data_sources', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=DataSourceListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DataSourcePatchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DataSourceService, DataSourcePatchReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_data_source_id(self, data_source_id):
        # type: (str) -> DataSourcePatchReqCall
        self.path_params['data_source_id'] = data_source_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[DataSourcePatchResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/search/v2/data_sources/:data_source_id', 'PATCH', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=DataSourcePatchResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DataSourceItemCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DataSourceItemService, Item, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_data_source_id(self, data_source_id):
        # type: (str) -> DataSourceItemCreateReqCall
        self.path_params['data_source_id'] = data_source_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/search/v2/data_sources/:data_source_id/items', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DataSourceItemDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DataSourceItemService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_data_source_id(self, data_source_id):
        # type: (str) -> DataSourceItemDeleteReqCall
        self.path_params['data_source_id'] = data_source_id
        return self

    def set_item_id(self, item_id):
        # type: (str) -> DataSourceItemDeleteReqCall
        self.path_params['item_id'] = item_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/search/v2/data_sources/:data_source_id/items/:item_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DataSourceItemGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DataSourceItemService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_data_source_id(self, data_source_id):
        # type: (str) -> DataSourceItemGetReqCall
        self.path_params['data_source_id'] = data_source_id
        return self

    def set_item_id(self, item_id):
        # type: (str) -> DataSourceItemGetReqCall
        self.path_params['item_id'] = item_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[DataSourceItemGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/search/v2/data_sources/:data_source_id/items/:item_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=DataSourceItemGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request as APIRequest, Response as APIResponse, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.members = MemberService(self)
        self.publics = PublicService(self)
        



class MemberService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (MemberCreateReqBody, str, str, int) -> MemberCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MemberCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (MemberDeleteReqBody, str, str, int) -> MemberDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MemberDeleteReqCall(self, body, request_opts=request_opts)

    def list(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (MemberListReqBody, str, str, int) -> MemberListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MemberListReqCall(self, body, request_opts=request_opts)

    def permitted(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (MemberPermittedReqBody, str, str, int) -> MemberPermittedReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MemberPermittedReqCall(self, body, request_opts=request_opts)

    def transfer(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (MemberTransferReqBody, str, str, int) -> MemberTransferReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MemberTransferReqCall(self, body, request_opts=request_opts)

    def update(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (MemberUpdateReqBody, str, str, int) -> MemberUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MemberUpdateReqCall(self, body, request_opts=request_opts)


class PublicService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def update(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (PublicUpdateReqBody, str, str, int) -> PublicUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return PublicUpdateReqCall(self, body, request_opts=request_opts)



class MemberCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MemberService, MemberCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[MemberCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/drive/permission/member/create', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=MemberCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MemberDeleteReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MemberService, MemberDeleteReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[MemberDeleteResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/drive/permission/member/delete', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=MemberDeleteResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MemberListReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MemberService, MemberListReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[MemberListResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/drive/permission/member/list', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=MemberListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MemberPermittedReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MemberService, MemberPermittedReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[MemberPermittedResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/drive/permission/member/permitted', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=MemberPermittedResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MemberTransferReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MemberService, MemberTransferReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[MemberTransferResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/drive/permission/member/transfer', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=MemberTransferResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MemberUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MemberService, MemberUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[MemberUpdateResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/drive/permission/member/update', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=MemberUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class PublicUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (PublicService, PublicUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[PublicUpdateResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/drive/permission/public/update', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=PublicUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request as APIRequest, Response as APIResponse, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.users = UserService(self)
        self.departments = DepartmentService(self)
        self.scopes = ScopeService(self)
        self.employee_type_enums = EmployeeTypeEnumService(self)
        self.custom_attrs = CustomAttrService(self)
        self.groups = GroupService(self)
        self.group_members = GroupMemberService(self)
        



class UserService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def delete(self, body, tenant_key=None, timeout=None):
        # type: (UserDeleteReqBody, str, int) -> UserDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return UserDeleteReqCall(self, body, request_opts=request_opts)

    def update(self, body, tenant_key=None, timeout=None):
        # type: (User, str, int) -> UserUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return UserUpdateReqCall(self, body, request_opts=request_opts)

    def create(self, body, tenant_key=None, timeout=None):
        # type: (User, str, int) -> UserCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return UserCreateReqCall(self, body, request_opts=request_opts)

    def patch(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (User, str, str, int) -> UserPatchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return UserPatchReqCall(self, body, request_opts=request_opts)

    def get(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> UserGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return UserGetReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> UserListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return UserListReqCall(self, request_opts=request_opts)


class DepartmentService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def get(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DepartmentGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DepartmentGetReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DepartmentListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DepartmentListReqCall(self, request_opts=request_opts)

    def patch(self, body, tenant_key=None, timeout=None):
        # type: (Department, str, int) -> DepartmentPatchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DepartmentPatchReqCall(self, body, request_opts=request_opts)

    def create(self, body, tenant_key=None, timeout=None):
        # type: (Department, str, int) -> DepartmentCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DepartmentCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> DepartmentDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DepartmentDeleteReqCall(self, request_opts=request_opts)

    def update(self, body, tenant_key=None, timeout=None):
        # type: (Department, str, int) -> DepartmentUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DepartmentUpdateReqCall(self, body, request_opts=request_opts)

    def parent(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DepartmentParentReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DepartmentParentReqCall(self, request_opts=request_opts)

    def search(self, body, user_access_token=None, timeout=None):
        # type: (DepartmentSearchReqBody, str, int) -> DepartmentSearchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DepartmentSearchReqCall(self, body, request_opts=request_opts)


class ScopeService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service


class EmployeeTypeEnumService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> EmployeeTypeEnumListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return EmployeeTypeEnumListReqCall(self, request_opts=request_opts)

    def create(self, body, tenant_key=None, timeout=None):
        # type: (EmployeeTypeEnum, str, int) -> EmployeeTypeEnumCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return EmployeeTypeEnumCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> EmployeeTypeEnumDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return EmployeeTypeEnumDeleteReqCall(self, request_opts=request_opts)

    def update(self, body, tenant_key=None, timeout=None):
        # type: (EmployeeTypeEnum, str, int) -> EmployeeTypeEnumUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return EmployeeTypeEnumUpdateReqCall(self, body, request_opts=request_opts)


class CustomAttrService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> CustomAttrListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return CustomAttrListReqCall(self, request_opts=request_opts)


class GroupService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, timeout=None):
        # type: (GroupCreateReqBody, str, int) -> GroupCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return GroupCreateReqCall(self, body, request_opts=request_opts)

    def simplelist(self, tenant_key=None, timeout=None):
        # type: (str, int) -> GroupSimplelistReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return GroupSimplelistReqCall(self, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> GroupDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return GroupDeleteReqCall(self, request_opts=request_opts)

    def get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> GroupGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return GroupGetReqCall(self, request_opts=request_opts)

    def patch(self, body, tenant_key=None, timeout=None):
        # type: (GroupPatchReqBody, str, int) -> GroupPatchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return GroupPatchReqCall(self, body, request_opts=request_opts)


class GroupMemberService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def simplelist(self, tenant_key=None, timeout=None):
        # type: (str, int) -> GroupMemberSimplelistReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return GroupMemberSimplelistReqCall(self, request_opts=request_opts)

    def add(self, body, tenant_key=None, timeout=None):
        # type: (GroupMemberAddReqBody, str, int) -> GroupMemberAddReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return GroupMemberAddReqCall(self, body, request_opts=request_opts)

    def remove(self, body, tenant_key=None, timeout=None):
        # type: (GroupMemberRemoveReqBody, str, int) -> GroupMemberRemoveReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return GroupMemberRemoveReqCall(self, body, request_opts=request_opts)



class CustomAttrListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (CustomAttrService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_page_size(self, page_size):
        # type: (int) -> CustomAttrListReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> CustomAttrListReqCall
        self.query_params['page_token'] = page_token
        return self

    def do(self):
        # type: () -> APIResponse[Type[CustomAttrListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/custom_attrs', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=CustomAttrListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DepartmentGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DepartmentService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_department_id(self, department_id):
        # type: (str) -> DepartmentGetReqCall
        self.path_params['department_id'] = department_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DepartmentGetReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> DepartmentGetReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DepartmentGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/departments/:department_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=DepartmentGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DepartmentListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DepartmentService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DepartmentListReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> DepartmentListReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def set_parent_department_id(self, parent_department_id):
        # type: (str) -> DepartmentListReqCall
        self.query_params['parent_department_id'] = parent_department_id
        return self

    def set_fetch_child(self, fetch_child):
        # type: (bool) -> DepartmentListReqCall
        self.query_params['fetch_child'] = fetch_child
        return self

    def set_page_token(self, page_token):
        # type: (str) -> DepartmentListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> DepartmentListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> APIResponse[Type[DepartmentListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/departments', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=DepartmentListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DepartmentPatchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DepartmentService, Department, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_department_id(self, department_id):
        # type: (str) -> DepartmentPatchReqCall
        self.path_params['department_id'] = department_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DepartmentPatchReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> DepartmentPatchReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DepartmentPatchResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/departments/:department_id', 'PATCH', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=DepartmentPatchResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DepartmentCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DepartmentService, Department, List[Any]) -> None

        self.service = service
        self.body = body
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DepartmentCreateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> DepartmentCreateReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def set_client_token(self, client_token):
        # type: (str) -> DepartmentCreateReqCall
        self.query_params['client_token'] = client_token
        return self

    def do(self):
        # type: () -> APIResponse[Type[DepartmentCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/departments', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=DepartmentCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DepartmentDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DepartmentService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_department_id(self, department_id):
        # type: (str) -> DepartmentDeleteReqCall
        self.path_params['department_id'] = department_id
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> DepartmentDeleteReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/departments/:department_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DepartmentUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DepartmentService, Department, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_department_id(self, department_id):
        # type: (str) -> DepartmentUpdateReqCall
        self.path_params['department_id'] = department_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DepartmentUpdateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> DepartmentUpdateReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DepartmentUpdateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/departments/:department_id', 'PUT', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=DepartmentUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DepartmentParentReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DepartmentService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DepartmentParentReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> DepartmentParentReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def set_department_id(self, department_id):
        # type: (str) -> DepartmentParentReqCall
        self.query_params['department_id'] = department_id
        return self

    def set_page_token(self, page_token):
        # type: (str) -> DepartmentParentReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> DepartmentParentReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> APIResponse[Type[DepartmentParentResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/departments/parent', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=DepartmentParentResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DepartmentSearchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DepartmentService, DepartmentSearchReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DepartmentSearchReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> DepartmentSearchReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def set_page_token(self, page_token):
        # type: (str) -> DepartmentSearchReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> DepartmentSearchReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> APIResponse[Type[DepartmentSearchResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/departments/search', 'POST', [ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=DepartmentSearchResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class EmployeeTypeEnumListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (EmployeeTypeEnumService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_page_token(self, page_token):
        # type: (str) -> EmployeeTypeEnumListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> EmployeeTypeEnumListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> APIResponse[Type[EmployeeTypeEnumListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/employee_type_enums', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=EmployeeTypeEnumListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class EmployeeTypeEnumCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (EmployeeTypeEnumService, EmployeeTypeEnum, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[EmployeeTypeEnumCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/contact/v3/employee_type_enums', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=EmployeeTypeEnumCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class EmployeeTypeEnumDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (EmployeeTypeEnumService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_enum_id(self, enum_id):
        # type: (str) -> EmployeeTypeEnumDeleteReqCall
        self.path_params['enum_id'] = enum_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/contact/v3/employee_type_enums/:enum_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class EmployeeTypeEnumUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (EmployeeTypeEnumService, EmployeeTypeEnum, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_enum_id(self, enum_id):
        # type: (str) -> EmployeeTypeEnumUpdateReqCall
        self.path_params['enum_id'] = enum_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[EmployeeTypeEnumUpdateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/contact/v3/employee_type_enums/:enum_id', 'PUT', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=EmployeeTypeEnumUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class GroupCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (GroupService, GroupCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[GroupCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/contact/v3/group', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=GroupCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class GroupSimplelistReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (GroupService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_page_size(self, page_size):
        # type: (int) -> GroupSimplelistReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> GroupSimplelistReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_type(self, type):
        # type: (int) -> GroupSimplelistReqCall
        self.query_params['type'] = type
        return self

    def do(self):
        # type: () -> APIResponse[Type[GroupSimplelistResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/group/simplelist', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=GroupSimplelistResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class GroupDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (GroupService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_group_id(self, group_id):
        # type: (str) -> GroupDeleteReqCall
        self.path_params['group_id'] = group_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/contact/v3/group/:group_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class GroupGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (GroupService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_group_id(self, group_id):
        # type: (str) -> GroupGetReqCall
        self.path_params['group_id'] = group_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[GroupGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/contact/v3/group/:group_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=GroupGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class GroupPatchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (GroupService, GroupPatchReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_group_id(self, group_id):
        # type: (str) -> GroupPatchReqCall
        self.path_params['group_id'] = group_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/contact/v3/group/:group_id', 'PATCH', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class GroupMemberSimplelistReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (GroupMemberService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_group_id(self, group_id):
        # type: (str) -> GroupMemberSimplelistReqCall
        self.path_params['group_id'] = group_id
        return self

    def set_page_size(self, page_size):
        # type: (int) -> GroupMemberSimplelistReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> GroupMemberSimplelistReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_member_id_type(self, member_id_type):
        # type: (str) -> GroupMemberSimplelistReqCall
        self.query_params['member_id_type'] = member_id_type
        return self

    def set_member_type(self, member_type):
        # type: (str) -> GroupMemberSimplelistReqCall
        self.query_params['member_type'] = member_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[GroupMemberSimplelistResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/group/:group_id/member/simplelist', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=GroupMemberSimplelistResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class GroupMemberAddReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (GroupMemberService, GroupMemberAddReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_group_id(self, group_id):
        # type: (str) -> GroupMemberAddReqCall
        self.path_params['group_id'] = group_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/contact/v3/group/:group_id/member/add', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class GroupMemberRemoveReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (GroupMemberService, GroupMemberRemoveReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_group_id(self, group_id):
        # type: (str) -> GroupMemberRemoveReqCall
        self.path_params['group_id'] = group_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/contact/v3/group/:group_id/member/remove', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserDeleteReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (UserService, UserDeleteReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id(self, user_id):
        # type: (str) -> UserDeleteReqCall
        self.path_params['user_id'] = user_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserDeleteReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/users/:user_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (UserService, User, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id(self, user_id):
        # type: (str) -> UserUpdateReqCall
        self.path_params['user_id'] = user_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserUpdateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> UserUpdateReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[UserUpdateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/users/:user_id', 'PUT', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=UserUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (UserService, User, List[Any]) -> None

        self.service = service
        self.body = body
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserCreateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> UserCreateReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def set_client_token(self, client_token):
        # type: (str) -> UserCreateReqCall
        self.query_params['client_token'] = client_token
        return self

    def do(self):
        # type: () -> APIResponse[Type[UserCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/users', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=UserCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserPatchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (UserService, User, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id(self, user_id):
        # type: (str) -> UserPatchReqCall
        self.path_params['user_id'] = user_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserPatchReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> UserPatchReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[UserPatchResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/users/:user_id', 'PATCH', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=UserPatchResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (UserService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id(self, user_id):
        # type: (str) -> UserGetReqCall
        self.path_params['user_id'] = user_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserGetReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> UserGetReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[UserGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/users/:user_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=UserGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (UserService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserListReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> UserListReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def set_department_id(self, department_id):
        # type: (str) -> UserListReqCall
        self.query_params['department_id'] = department_id
        return self

    def set_page_token(self, page_token):
        # type: (str) -> UserListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> UserListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> APIResponse[Type[UserListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/contact/v3/users', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=UserListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
from ....event.model.event import *
import attr




@to_json_decorator
@attr.s
class WorkplaceWidget(object):
    min_lark_version = attr.ib(type=str, default=None, metadata={'json': 'min_lark_version'})


@to_json_decorator
@attr.s
class WebApp(object):
    pc_url = attr.ib(type=str, default=None, metadata={'json': 'pc_url'})
    mobile_url = attr.ib(type=str, default=None, metadata={'json': 'mobile_url'})


@to_json_decorator
@attr.s
class UsageTrendItem(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["timestamp", "page_view", "unique_visitor"])
    timestamp = attr.ib(type=int, default=None, metadata={'json': 'timestamp'})
    page_view = attr.ib(type=int, default=None, metadata={'json': 'page_view'})
    unique_visitor = attr.ib(type=int, default=None, metadata={'json': 'unique_visitor'})


@to_json_decorator
@attr.s
class AppUsageTrendItems(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    trend = attr.ib(type=List[UsageTrendItem], default=None, metadata={'json': 'trend'})


@to_json_decorator
@attr.s
class AppMessageTrendItem(object):
    chat_type = attr.ib(type=str, default=None, metadata={'json': 'chat_type'})
    event_type = attr.ib(type=str, default=None, metadata={'json': 'event_type'})
    message_type = attr.ib(type=str, default=None, metadata={'json': 'message_type'})
    trend = attr.ib(type=List[UsageTrendItem], default=None, metadata={'json': 'trend'})


@to_json_decorator
@attr.s
class PlusMenu(object):
    pc_app_link = attr.ib(type=str, default=None, metadata={'json': 'pc_app_link'})
    mobile_app_link = attr.ib(type=str, default=None, metadata={'json': 'mobile_app_link'})


@to_json_decorator
@attr.s
class NavigateMeta(object):
    version = attr.ib(type=str, default=None, metadata={'json': 'version'})
    image_url = attr.ib(type=str, default=None, metadata={'json': 'image_url'})
    hover_image_url = attr.ib(type=str, default=None, metadata={'json': 'hover_image_url'})


@to_json_decorator
@attr.s
class Navigate(object):
    pc = attr.ib(type=NavigateMeta, default=None, metadata={'json': 'pc'})
    mobile = attr.ib(type=NavigateMeta, default=None, metadata={'json': 'mobile'})


@to_json_decorator
@attr.s
class MsgActionI18nInfo(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class MsgAction(object):
    pc_app_link = attr.ib(type=str, default=None, metadata={'json': 'pc_app_link'})
    mobile_app_link = attr.ib(type=str, default=None, metadata={'json': 'mobile_app_link'})
    i18n = attr.ib(type=List[MsgActionI18nInfo], default=None, metadata={'json': 'i18n'})


@to_json_decorator
@attr.s
class MessageActionI18nInfo(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class MessageAction(object):
    pc_app_link = attr.ib(type=str, default=None, metadata={'json': 'pc_app_link'})
    mobile_app_link = attr.ib(type=str, default=None, metadata={'json': 'mobile_app_link'})
    i18n = attr.ib(type=List[MessageActionI18nInfo], default=None, metadata={'json': 'i18n'})


@to_json_decorator
@attr.s
class Gadget(object):
    enable_pc_mode = attr.ib(type=int, default=None, metadata={'json': 'enable_pc_mode'})
    schema_urls = attr.ib(type=List[str], default=None, metadata={'json': 'schema_urls'})
    pc_use_mobile_pkg = attr.ib(type=bool, default=None, metadata={'json': 'pc_use_mobile_pkg'})
    pc_version = attr.ib(type=str, default=None, metadata={'json': 'pc_version'})
    mobile_version = attr.ib(type=str, default=None, metadata={'json': 'mobile_version'})
    mobile_min_lark_version = attr.ib(type=str, default=None, metadata={'json': 'mobile_min_lark_version'})
    pc_min_lark_version = attr.ib(type=str, default=None, metadata={'json': 'pc_min_lark_version'})


@to_json_decorator
@attr.s
class CloudDocI18nInfo(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    read_description = attr.ib(type=str, default=None, metadata={'json': 'read_description'})
    write_description = attr.ib(type=str, default=None, metadata={'json': 'write_description'})


@to_json_decorator
@attr.s
class CloudDoc(object):
    space_url = attr.ib(type=str, default=None, metadata={'json': 'space_url'})
    i18n = attr.ib(type=List[CloudDocI18nInfo], default=None, metadata={'json': 'i18n'})
    icon_url = attr.ib(type=str, default=None, metadata={'json': 'icon_url'})
    mode = attr.ib(type=int, default=None, metadata={'json': 'mode'})


@to_json_decorator
@attr.s
class ClientBadgeNum(object):
    web_app = attr.ib(type=int, default=None, metadata={'json': 'web_app'})
    gadget = attr.ib(type=int, default=None, metadata={'json': 'gadget'})


@to_json_decorator
@attr.s
class AppBadge(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["user_id", "version"])
    user_id = attr.ib(type=int, default=None, metadata={'json': 'user_id'})
    version = attr.ib(type=int, default=None, metadata={'json': 'version'})
    pc = attr.ib(type=ClientBadgeNum, default=None, metadata={'json': 'pc'})
    mobile = attr.ib(type=ClientBadgeNum, default=None, metadata={'json': 'mobile'})


@to_json_decorator
@attr.s
class Bot(object):
    card_request_url = attr.ib(type=str, default=None, metadata={'json': 'card_request_url'})


@to_json_decorator
@attr.s
class BlockI18nInfo(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class DocsBlock(object):
    block_type_id = attr.ib(type=str, default=None, metadata={'json': 'block_type_id'})
    i18n = attr.ib(type=List[BlockI18nInfo], default=None, metadata={'json': 'i18n'})
    mobile_icon_url = attr.ib(type=str, default=None, metadata={'json': 'mobile_icon_url'})
    pc_icon_url = attr.ib(type=str, default=None, metadata={'json': 'pc_icon_url'})


@to_json_decorator
@attr.s
class AppAbility(object):
    gadget = attr.ib(type=Gadget, default=None, metadata={'json': 'gadget'})
    web_app = attr.ib(type=WebApp, default=None, metadata={'json': 'web_app'})
    bot = attr.ib(type=Bot, default=None, metadata={'json': 'bot'})
    workplace_widgets = attr.ib(type=List[WorkplaceWidget], default=None, metadata={'json': 'workplace_widgets'})
    navigate = attr.ib(type=Navigate, default=None, metadata={'json': 'navigate'})
    cloud_doc = attr.ib(type=CloudDoc, default=None, metadata={'json': 'cloud_doc'})
    docs_blocks = attr.ib(type=List[DocsBlock], default=None, metadata={'json': 'docs_blocks'})
    message_action = attr.ib(type=MessageAction, default=None, metadata={'json': 'message_action'})
    plus_menu = attr.ib(type=PlusMenu, default=None, metadata={'json': 'plus_menu'})


@to_json_decorator
@attr.s
class Block(object):
    block_type_id = attr.ib(type=str, default=None, metadata={'json': 'block_type_id'})
    version_id = attr.ib(type=str, default=None, metadata={'json': 'version_id'})
    i18n = attr.ib(type=List[BlockI18nInfo], default=None, metadata={'json': 'i18n'})
    mobile_icon_url = attr.ib(type=str, default=None, metadata={'json': 'mobile_icon_url'})
    pc_icon_url = attr.ib(type=str, default=None, metadata={'json': 'pc_icon_url'})


@to_json_decorator
@attr.s
class AppVisibleList(object):
    open_ids = attr.ib(type=List[int], default=None, metadata={'json': 'open_ids'})
    department_ids = attr.ib(type=List[int], default=None, metadata={'json': 'department_ids'})


@to_json_decorator
@attr.s
class ApplicationVisibility(object):
    is_all = attr.ib(type=bool, default=None, metadata={'json': 'is_all'})
    visible_list = attr.ib(type=AppVisibleList, default=None, metadata={'json': 'visible_list'})
    invisible_list = attr.ib(type=AppVisibleList, default=None, metadata={'json': 'invisible_list'})


@to_json_decorator
@attr.s
class AppVisibility(object):
    is_all = attr.ib(type=bool, default=None, metadata={'json': 'is_all'})
    visible_list = attr.ib(type=AppVisibleList, default=None, metadata={'json': 'visible_list'})
    invisible_list = attr.ib(type=AppVisibleList, default=None, metadata={'json': 'invisible_list'})


@to_json_decorator
@attr.s
class AppVersionRemark(object):
    remark = attr.ib(type=str, default=None, metadata={'json': 'remark'})
    update_remark = attr.ib(type=str, default=None, metadata={'json': 'update_remark'})
    visibility = attr.ib(type=AppVisibility, default=None, metadata={'json': 'visibility'})


@to_json_decorator
@attr.s
class AppScope(object):
    scope = attr.ib(type=str, default=None, metadata={'json': 'scope'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    level = attr.ib(type=str, default=None, metadata={'json': 'level'})


@to_json_decorator
@attr.s
class AppI18nInfo(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    help_use = attr.ib(type=str, default=None, metadata={'json': 'help_use'})


@to_json_decorator
@attr.s
class ApplicationAppVersion(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["version_id", "create_time", "publish_time"])
    app_id = attr.ib(type=str, default=None, metadata={'json': 'app_id'})
    version = attr.ib(type=str, default=None, metadata={'json': 'version'})
    version_id = attr.ib(type=int, default=None, metadata={'json': 'version_id'})
    app_name = attr.ib(type=str, default=None, metadata={'json': 'app_name'})
    avatar_url = attr.ib(type=str, default=None, metadata={'json': 'avatar_url'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    scopes = attr.ib(type=List[AppScope], default=None, metadata={'json': 'scopes'})
    back_home_url = attr.ib(type=str, default=None, metadata={'json': 'back_home_url'})
    i18n = attr.ib(type=List[AppI18nInfo], default=None, metadata={'json': 'i18n'})
    common_categories = attr.ib(type=List[str], default=None, metadata={'json': 'common_categories'})
    events = attr.ib(type=List[str], default=None, metadata={'json': 'events'})
    status = attr.ib(type=int, default=None, metadata={'json': 'status'})
    create_time = attr.ib(type=int, default=None, metadata={'json': 'create_time'})
    publish_time = attr.ib(type=int, default=None, metadata={'json': 'publish_time'})
    ability = attr.ib(type=AppAbility, default=None, metadata={'json': 'ability'})
    remark = attr.ib(type=AppVersionRemark, default=None, metadata={'json': 'remark'})


@to_json_decorator
@attr.s
class Application(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["creator_id", "online_version_id", "unaudit_version_id"])
    app_id = attr.ib(type=str, default=None, metadata={'json': 'app_id'})
    creator_id = attr.ib(type=int, default=None, metadata={'json': 'creator_id'})
    status = attr.ib(type=int, default=None, metadata={'json': 'status'})
    scene_type = attr.ib(type=int, default=None, metadata={'json': 'scene_type'})
    redirect_urls = attr.ib(type=List[str], default=None, metadata={'json': 'redirect_urls'})
    online_version_id = attr.ib(type=int, default=None, metadata={'json': 'online_version_id'})
    unaudit_version_id = attr.ib(type=int, default=None, metadata={'json': 'unaudit_version_id'})
    app_name = attr.ib(type=str, default=None, metadata={'json': 'app_name'})
    avatar_url = attr.ib(type=str, default=None, metadata={'json': 'avatar_url'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    scopes = attr.ib(type=List[AppScope], default=None, metadata={'json': 'scopes'})
    back_home_url = attr.ib(type=str, default=None, metadata={'json': 'back_home_url'})
    i18n = attr.ib(type=List[AppI18nInfo], default=None, metadata={'json': 'i18n'})
    primary_language = attr.ib(type=str, default=None, metadata={'json': 'primary_language'})
    common_categories = attr.ib(type=List[str], default=None, metadata={'json': 'common_categories'})


@to_json_decorator
@attr.s
class UserId(object):
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})
    union_id = attr.ib(type=str, default=None, metadata={'json': 'union_id'})


@to_json_decorator
@attr.s
class User(object):
    user_id = attr.ib(type=UserId, default=None, metadata={'json': 'user_id'})


@to_json_decorator
@attr.s
class AppCommonCategory(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    category = attr.ib(type=str, default=None, metadata={'json': 'category'})


@to_json_decorator
@attr.s
class AppCustomCategory(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    app_ids = attr.ib(type=List[str], default=None, metadata={'json': 'app_ids'})


@to_json_decorator
@attr.s
class AppCustomCategoryI18nInfo(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class AppScopeI18nInfo(object):
    i18n_key = attr.ib(type=str, default=None, metadata={'json': 'i18n_key'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})


@to_json_decorator
@attr.s
class AppScopes(object):
    high_level_scopes = attr.ib(type=List[str], default=None, metadata={'json': 'high_level_scopes'})
    low_level_scopes = attr.ib(type=List[str], default=None, metadata={'json': 'low_level_scopes'})


@to_json_decorator
@attr.s
class AppVersionId(object):
    version = attr.ib(type=str, default=None, metadata={'json': 'version'})
    version_id = attr.ib(type=str, default=None, metadata={'json': 'version_id'})


@to_json_decorator
@attr.s
class MessageOverviewItem(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["page_view", "unique_visitor"])
    page_view = attr.ib(type=int, default=None, metadata={'json': 'page_view'})
    unique_visitor = attr.ib(type=int, default=None, metadata={'json': 'unique_visitor'})
    chat_type = attr.ib(type=str, default=None, metadata={'json': 'chat_type'})
    message_type = attr.ib(type=str, default=None, metadata={'json': 'message_type'})
    event_type = attr.ib(type=str, default=None, metadata={'json': 'event_type'})


@to_json_decorator
@attr.s
class Miniprogram(object):
    enable_pc_mode = attr.ib(type=int, default=None, metadata={'json': 'enable_pc_mode'})
    schema_urls = attr.ib(type=List[str], default=None, metadata={'json': 'schema_urls'})
    pc_use_mobile_pkg = attr.ib(type=bool, default=None, metadata={'json': 'pc_use_mobile_pkg'})
    pc_version_id = attr.ib(type=str, default=None, metadata={'json': 'pc_version_id'})
    mobile_version_id = attr.ib(type=str, default=None, metadata={'json': 'mobile_version_id'})
    mobile_min_lark_version = attr.ib(type=str, default=None, metadata={'json': 'mobile_min_lark_version'})
    pc_min_lark_version = attr.ib(type=str, default=None, metadata={'json': 'pc_min_lark_version'})


@to_json_decorator
@attr.s
class Scope(object):
    scope_name = attr.ib(type=str, default=None, metadata={'json': 'scope_name'})
    grant_status = attr.ib(type=int, default=None, metadata={'json': 'grant_status'})


@to_json_decorator
@attr.s
class UsageOverviewItem(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["page_view", "unique_visitor"])
    page_view = attr.ib(type=int, default=None, metadata={'json': 'page_view'})
    unique_visitor = attr.ib(type=int, default=None, metadata={'json': 'unique_visitor'})
    department_id = attr.ib(type=str, default=None, metadata={'json': 'department_id'})


@to_json_decorator
@attr.s
class UsageUser(object):
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})


@to_json_decorator
@attr.s
class ApplicationAppUsage(object):
    metric_name = attr.ib(type=str, default=None, metadata={'json': 'metric_name'})
    metric_value = attr.ib(type=int, default=None, metadata={'json': 'metric_value'})



@to_json_decorator
@attr.s
class ApplicationAppUsageOverviewReqBody(object):
    date = attr.ib(type=str, default=None, metadata={'json': 'date'})
    cycle_type = attr.ib(type=int, default=None, metadata={'json': 'cycle_type'})
    department_id = attr.ib(type=str, default=None, metadata={'json': 'department_id'})
    ability = attr.ib(type=str, default=None, metadata={'json': 'ability'})


@attr.s
class ApplicationAppUsageOverviewResult(object):
    items = attr.ib(type=List[ApplicationAppUsage], default=None, metadata={'json': 'items'})


@attr.s
class ApplicationVisibilityAddedEventData(object):
    users = attr.ib(type=List[User], default=None, metadata={'json': 'users'})
    source = attr.ib(type=int, default=None, metadata={'json': 'source'})


@attr.s
class ApplicationVisibilityAddedEvent(BaseEventV2):
    event = attr.ib(type=ApplicationVisibilityAddedEventData, default=None)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class SchemaDisplayOption(object):
    display_label = attr.ib(type=str, default=None, metadata={'json': 'display_label'})
    display_type = attr.ib(type=str, default=None, metadata={'json': 'display_type'})


@to_json_decorator
@attr.s
class SchemaPropertyDefinition(object):
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    is_returnable = attr.ib(type=bool, default=None, metadata={'json': 'is_returnable'})
    is_repeatable = attr.ib(type=bool, default=None, metadata={'json': 'is_repeatable'})
    is_sortable = attr.ib(type=bool, default=None, metadata={'json': 'is_sortable'})
    is_facetable = attr.ib(type=bool, default=None, metadata={'json': 'is_facetable'})
    is_wildcard_searchable = attr.ib(type=bool, default=None, metadata={'json': 'is_wildcard_searchable'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})
    display_options = attr.ib(type=SchemaDisplayOption, default=None, metadata={'json': 'display_options'})


@to_json_decorator
@attr.s
class Schema(object):
    property_definitions = attr.ib(type=List[SchemaPropertyDefinition], default=None, metadata={'json': 'property_definitions'})
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})


@to_json_decorator
@attr.s
class ItemMetadata(object):
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})
    source_url = attr.ib(type=str, default=None, metadata={'json': 'source_url'})
    create_time = attr.ib(type=int, default=None, metadata={'json': 'create_time'})
    update_time = attr.ib(type=int, default=None, metadata={'json': 'update_time'})


@to_json_decorator
@attr.s
class ItemContent(object):
    format = attr.ib(type=str, default=None, metadata={'json': 'format'})
    content_data = attr.ib(type=str, default=None, metadata={'json': 'content_data'})


@to_json_decorator
@attr.s
class Acl(object):
    access = attr.ib(type=str, default=None, metadata={'json': 'access'})
    value = attr.ib(type=str, default=None, metadata={'json': 'value'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})


@to_json_decorator
@attr.s
class Item(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    acl = attr.ib(type=List[Acl], default=None, metadata={'json': 'acl'})
    metadata = attr.ib(type=ItemMetadata, default=None, metadata={'json': 'metadata'})
    structured_data = attr.ib(type=str, default=None, metadata={'json': 'structured_data'})
    content = attr.ib(type=ItemContent, default=None, metadata={'json': 'content'})
    field_acl = attr.ib(type=str, default=None, metadata={'json': 'field_acl'})


@to_json_decorator
@attr.s
class ConnectDataSource(object):
    service_url = attr.ib(type=str, default=None, metadata={'json': 'service_url'})
    project_name = attr.ib(type=str, default=None, metadata={'json': 'project_name'})
    display_name = attr.ib(type=str, default=None, metadata={'json': 'display_name'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    icon_url = attr.ib(type=str, default=None, metadata={'json': 'icon_url'})
    project_description = attr.ib(type=str, default=None, metadata={'json': 'project_description'})
    contact_email = attr.ib(type=str, default=None, metadata={'json': 'contact_email'})
    tenant_name = attr.ib(type=str, default=None, metadata={'json': 'tenant_name'})


@to_json_decorator
@attr.s
class DataSource(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    state = attr.ib(type=int, default=None, metadata={'json': 'state'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    create_time = attr.ib(type=str, default=None, metadata={'json': 'create_time'})
    update_time = attr.ib(type=str, default=None, metadata={'json': 'update_time'})
    is_exceed_quota = attr.ib(type=bool, default=None, metadata={'json': 'is_exceed_quota'})
    icon_url = attr.ib(type=str, default=None, metadata={'json': 'icon_url'})
    template = attr.ib(type=str, default=None, metadata={'json': 'template'})




@attr.s
class DataSourceCreateResult(object):
    data_source = attr.ib(type=DataSource, default=None, metadata={'json': 'data_source'})





@attr.s
class DataSourceGetResult(object):
    data_source = attr.ib(type=DataSource, default=None, metadata={'json': 'data_source'})



@attr.s
class DataSourceListResult(object):
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    items = attr.ib(type=List[DataSource], default=None, metadata={'json': 'items'})


@to_json_decorator
@attr.s
class DataSourcePatchReqBody(object):
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    state = attr.ib(type=int, default=None, metadata={'json': 'state'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})


@attr.s
class DataSourcePatchResult(object):
    data_source = attr.ib(type=DataSource, default=None, metadata={'json': 'data_source'})







@attr.s
class DataSourceItemGetResult(object):
    item = attr.ib(type=Item, default=None, metadata={'json': 'item'})